==> goggles-0.8.0.tar.bz2: goggles-0.8.0/include/dvdapp.h <==
/*******************************************************************************
*               Goggles - Graphical User Interface for OGLE                    *
********************************************************************************
*        Copyright (C) 2002-2005 by Sander Jansen. All Rights Reserved         *
*                               ---                                            *
* This program is free software; you can redistribute it and/or modify         *
* it under the terms of the GNU General Public License as published by         *
* the Free Software Foundation; either version 2 of the License, or            *
* (at your option) any later version.                                          *
*                                                                              *
* This program is distributed in the hope that it will be useful,              *
* but WITHOUT ANY WARRANTY; without even the implied warranty of               *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                *
* GNU General Public License for more details.                                 *
* You should have received a copy of the GNU General Public License            *
* along with this program; if not, write to the Free Software                  *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    *
*******************************************************************************/

/*
$Id$
*/

#ifndef DVD_APPLICATION
#define DVD_APPLICATION

#include <fx.h>

#ifdef HAVE_XV
class XVController;
#endif

class DVDApp : public FXApp {
FXDECLARE(DVDApp)
private:
#ifdef HAVE_XV
    XVController * xvcontrol;
#endif
protected:
    virtual FXbool dispatchEvent(FXRawEvent & event);
public:
    DVDApp();
#ifdef HAVE_XV
    XVController * getXVControl() { return xvcontrol;}
#endif
    virtual void create();

    virtual ~DVDApp();
    };
#endif

==> goggles-0.9.1.tar.bz2: goggles-0.9.1/include/dvdapp.h <==
/*******************************************************************************
*               Goggles - Graphical User Interface for OGLE                    *
********************************************************************************
*        Copyright (C) 2002-2005 by Sander Jansen. All Rights Reserved         *
*                               ---                                            *
* This program is free software; you can redistribute it and/or modify         *
* it under the terms of the GNU General Public License as published by         *
* the Free Software Foundation; either version 2 of the License, or            *
* (at your option) any later version.                                          *
*                                                                              *
* This program is distributed in the hope that it will be useful,              *
* but WITHOUT ANY WARRANTY; without even the implied warranty of               *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                *
* GNU General Public License for more details.                                 *
* You should have received a copy of the GNU General Public License            *
* along with this program; if not, write to the Free Software                  *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    *
*******************************************************************************/

/*
$Id$
*/

#ifndef DVD_APPLICATION
#define DVD_APPLICATION

#include <fx.h>

#ifdef HAVE_XV
class XVController;
#endif

class DVDApp : public FXApp {
FXDECLARE(DVDApp)
private:
#ifdef HAVE_XV
    XVController * xvcontrol;
#endif
protected:
    virtual bool dispatchEvent(FXRawEvent & event);
public:
    DVDApp();
#ifdef HAVE_XV
    XVController * getXVControl() { return xvcontrol;}
#endif
    virtual void create();

    virtual ~DVDApp();
    };
#endif
